@@ -3,7 +3,9 @@ import os
 import sys
 
 __package__ = "meld"
-__version__ = "3.18.2"
+__version__ = "3.20.1"
+
+APPLICATION_ID = "org.gnome.meld"
 
 DATADIR = "/usr/local/share/meld"
 LOCALEDIR = "/usr/local/share/locale"
@@ -12,9 +14,14 @@ LOCALEDIR = "/usr/local/share/locale"
 DATADIR_IS_UNINSTALLED = False
 PYTHON_REQUIREMENT_TUPLE = (3, 3)
 
+
 # Installed from main script
-_ = lambda x: x
-ngettext = lambda x, *args: x
+def no_translation(gettext_string, *args):
+    return gettext_string
+
+
+_ = no_translation
+ngettext = no_translation
 
 
 def frozen():
@@ -26,12 +33,6 @@ def frozen():
     LOCALEDIR = os.path.join(melddir, "share", "mo")
     DATADIR_IS_UNINSTALLED = True
 
-    # This first bit should be unnecessary, but some things (GTK icon theme
-    # location, GSettings schema location) don't fall back correctly.
-    data_dir = os.environ.get('XDG_DATA_DIRS', "/usr/local/share/:/usr/share/")
-    data_dir = ":".join((melddir, data_dir))
-    os.environ['XDG_DATA_DIRS'] = data_dir
-
 
 def uninstalled():
     global DATADIR, LOCALEDIR, DATADIR_IS_UNINSTALLED
@@ -42,8 +43,6 @@ def uninstalled():
     LOCALEDIR = os.path.join(melddir, "build", "mo")
     DATADIR_IS_UNINSTALLED = True
 
-    # This first bit should be unnecessary, but some things (GTK icon theme
-    # location, GSettings schema location) don't fall back correctly.
-    data_dir = os.environ.get('XDG_DATA_DIRS', "/usr/local/share/:/usr/share/")
-    data_dir = ":".join((melddir, data_dir))
-    os.environ['XDG_DATA_DIRS'] = data_dir
\ No newline at end of file
+
+def ui_file(filename):
+    return os.path.join(DATADIR, "ui", filename)
\ No newline at end of file
